/*
 * Copyright (c) 2006 Mellanox Technologies Ltd. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * $Id: ibnl_scanner.ll,v 1.4 2005/02/23 21:08:37 eitan Exp $
 */

%{

/* #define DEBUG 1 */

#define	yymaxdepth libsdp_maxdepth
#define	yyparse	libsdp_parse
#define	yylex	libsdp_lex
#define	yyerror	libsdp_error
#define	yylval	libsdp_lval
#define	yychar	libsdp_char
#define	yydebug	libsdp_debug
#define	yypact	libsdp_pact
#define	yyr1	libsdp_r1
#define	yyr2	libsdp_r2
#define	yydef	libsdp_def
#define	yychk	libsdp_chk
#define	yypgo	libsdp_pgo
#define	yyact	libsdp_act
#define	yyexca	libsdp_exca
#define  yyerrflag libsdp_errflag
#define  yynerrs	libsdp_nerrs
#define	yyps	libsdp_ps
#define	yypv	libsdp_pv
#define	yys	libsdp_s
#define	yy_yys	libsdp_yys
#define	yystate	libsdp_state
#define	yytmp	libsdp_tmp
#define	yyv	libsdp_v
#define	yy_yyv	libsdp_yyv
#define	yyval	libsdp_val
#define	yylloc	libsdp_lloc
#define yyreds	libsdp_reds
#define yytoks	libsdp_toks
#define yylhs	libsdp_yylhs
#define yylen	libsdp_yylen
#define yydefred libsdp_yydefred
#define yydgoto	libsdp_yydgoto
#define yysindex libsdp_yysindex
#define yyrindex libsdp_yyrindex
#define yygindex libsdp_yygindex
#define yytable	 libsdp_yytable
#define yycheck	 libsdp_yycheck
#define yyname   libsdp_yyname
#define yyrule   libsdp_yyrule

#include <string.h>
#include <stdio.h>
#include "config_parser.h"
extern long __sdp_config_line_num;
%}
%s CANNAME
%%

^[ \t]*#.* {}

([1-9][0-9]*|0) { 
  yylval.ival = atoi(yytext);
#ifdef DEBUG
  printf("INT:%d\n",yylval.ival);
#endif
  return INT;
}

log {
  yylval.ival = LOG;
#ifdef DEBUG
  printf("LOG\n");
#endif
  return LOG;
}

destination {
  yylval.ival = DEST;
#ifdef DEBUG
  printf("DEST\n");
#endif
  return DEST;
}

min-level {
  yylval.ival = LEVEL;
#ifdef DEBUG
  printf("LEVEL\n");
#endif
  return LEVEL;
}

stderr {
  yylval.ival = STDERR;
#ifdef DEBUG
  printf("STDERR\n");
#endif
  return STDERR;
}

syslog {
  yylval.ival = SYSLOG;
#ifdef DEBUG
  printf("SYSLOG\n");
#endif
  return SYSLOG;
}

file {
  yylval.ival = FILENAME;
#ifdef DEBUG
  printf("FILENAME\n");
#endif
  BEGIN(CANNAME);
  return FILENAME;
}

use {
  yylval.ival = USE;
#ifdef DEBUG
  printf("USE\n");
#endif
  return USE;
}

tcp {
  yylval.ival = TCP;
#ifdef DEBUG
  printf("TCP\n");
#endif
  return TCP;
}

sdp {
  yylval.ival = SDP;
#ifdef DEBUG
  printf("SDP\n");
#endif
  return SDP;
}

both {
  yylval.ival = BOTH;
#ifdef DEBUG
  printf("BOTH\n");
#endif
  return BOTH;
}

client|connect {
  yylval.ival = CLIENT;
#ifdef DEBUG
  printf("CLIENT\n");
#endif
  BEGIN(CANNAME);
  return CLIENT;
}

server|listen {
  yylval.ival = SERVER;
#ifdef DEBUG
  printf("SERVER\n");
#endif
  BEGIN(CANNAME);
  return SERVER;
}

<CANNAME>[^ \t\n]+ {
	 yylval.sval = (char *)malloc(strlen(yytext) + 1);
    strcpy(yylval.sval, yytext);
#ifdef DEBUG
	 printf("NAME:%s\n",yylval.sval);
#endif
    BEGIN(0);
	 return (NAME);
}

\n {
  __sdp_config_line_num++;
#ifdef DEBUG
  printf("LINE\n");
#endif
  yylval.ival = LINE;
  return(LINE);
}

[#][^\n]* {
  __sdp_config_line_num++;
}

[ \t]+ {}

. {
#ifdef DEBUG
  printf("CHAR:%c\n",yytext[0]);
#endif
  return(yytext[0]);
}

%%

int yywrap ()
{
  return (1);
}

